@@ -3,16 +3,33 @@ context("encode")
 ## TODO
 ## - sf_GEOMETRY
 
+test_that("google's example encodes correctly", {
+  
+  df <- data.frame(lat = c(38.5, 40.7, 43.252),
+                   lon = c(-120.2, -120.95, -126.453))
+  
+  expect_true(encode(df) == "_p~iF~ps|U_ulLnnqC_mqNvxq`@")
+})
+
+test_that("answers are same as other implementations", {
+  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  
+  df <- data.frame(lat = c(38.5, 40.7, 43.252),lon = c(-120.2, -120.95, -126.453))
+  expect_true(gepaf::encodePolyline(df) == encode(df))
+  df <- data.frame(lat = c(41.8249, 41.8300, 41.8288, 41.8339, 41.8380),
+                   lon = c(-87.7200, -87.7043, -87.6940, -87.6833, -87.6703))
+  expect_true(gepaf::encodePolyline(df) == encode(df))
+})
 
 test_that("encode coordinates algorithim works", {
   
   testthat::skip_on_cran()
-
   expect_equal(
     encodeCoordinates(lon = c(144.9731, 144.9729, 144.9731), 
                       lat = c(-37.8090, -37.8094, -37.8083)),
-    "dqweFy`zsZnAd@yEe@"
-  )
+    "dqweFy`zsZnAd@yEe@")
 })
 
 
@@ -25,30 +42,15 @@ test_that("*POINTs are encoded", {
   
   ## sfc
   point <- sf::st_sfc(sf::st_point(x = c(144, -37)))
-
-  expect_true(
-    encode(point)[[1]] == encode14437
-  )
+  expect_true(encode(point)[[1]] == encode14437)
 
   ## sf
   sf <- sf::st_sf(point)
-
-  expect_true(
-    encode(sf)[, 'point'][[1]] == encode14437
-  )
-
+  expect_true(encode(sf)[, 'point'][[1]] == encode14437)
   multipoint <- sf::st_sfc(sf::st_multipoint(x = matrix(c(144, 145, -37, -37), ncol = 2)))
-
-  expect_true(
-    all(encode(multipoint)[[1]] %in% c(encode14437, encode14537))
-  )
-
+  expect_true(all(encode(multipoint)[[1]] %in% c(encode14437, encode14537)))
   sf <- sf::st_sf(multipoint)
-
-  expect_true(
-    all(encode(sf)[, 'multipoint'][[1]]  %in% c(encode14437, encode14537))
-  )
-
+  expect_true(all(encode(sf)[, 'multipoint'][[1]]  %in% c(encode14437, encode14537)))
 })
 
 
@@ -57,25 +59,11 @@ test_that("UNKNOWN geometry & sf type", {
   testthat::skip_on_cran()
   
   point <- sf::st_sfc(sf::st_point(x = c(144, -37)))
-  
   class(point) <- c("sfc_NEWPOINT", "sfc")
-  
-  expect_error(
-    encode(point),
-    "encoding this sf type is currently not supported"
-  )
-  
+  expect_error(encode(point),"encoding this sf type is currently not supported")
   point <- sf::st_sfc(sf::st_point(x = c(144, -37)))
-  
   enc <- encode(point)
-  
-  expect_error(
-    polyline_wkt(enc),
-    "I was expecting an sfencoded object or an encoded_column"
-  )
-  
-#  point <- sf::st_sfc(sf::st_point(x = c(144, -37)), sf::st_point(x = c(144, -37)))
-  
+  expect_error(polyline_wkt(enc),"I was expecting an sfencoded object or an encoded_column")
 })
 
 test_that("*LINES are encoded", {
@@ -84,17 +72,9 @@ test_that("*LINES are encoded", {
   
   encodedLine <- "~py`F__|mZ~oR_pR~oR}oR"
   line <- sf::st_sfc(sf::st_linestring(matrix(c(144, 144.1, 144.2, -37, -37.1, -37.2), ncol = 2)))
-
-  expect_true(
-    encode(line)[[1]] == encodedLine
-  )
-
+  expect_true(encode(line)[[1]] == encodedLine)
   sf <- sf::st_sf(line)
-  
-  expect_true(
-    encode(sf)[[1]] == encodedLine
-  )
-  
+  expect_true(encode(sf)[[1]] == encodedLine)
   multilinestring <- sf::st_sfc(
     sf::st_multilinestring(
       list(
@@ -103,15 +83,8 @@ test_that("*LINES are encoded", {
         )
       )
     )
- 
-  expect_true(
-    encode(multilinestring)[[1]][1] == encodedLine
-  )
-  
-  expect_true(
-    encode(multilinestring)[[1]][2] == encodedLine
-  )
-  
+  expect_true(encode(multilinestring)[[1]][1] == encodedLine)
+  expect_true(encode(multilinestring)[[1]][2] == encodedLine)
 })
 
 test_that("*POLYGONS are encoded", {
@@ -122,30 +95,15 @@ test_that("*POLYGONS are encoded", {
   polygon <- sf::st_sfc(sf::st_polygon(
     list(matrix(c(144, 144.1, 144.2, 144, -37, -37.1, -37.2, -37), ncol = 2))
     ))
-  
-  expect_true(
-    encode(polygon)[[1]] == "~py`F__|mZ~oR_pR~oR}oR_af@|`f@"
-  )
-  
+  expect_true(encode(polygon)[[1]] == "~py`F__|mZ~oR_pR~oR}oR_af@|`f@")
   sf <- sf::st_sf(geo = polygon)
-  
-  expect_true(
-    encode(sf)[[1]] == "~py`F__|mZ~oR_pR~oR}oR_af@|`f@"
-  )
-  
+  expect_true(encode(sf)[[1]] == "~py`F__|mZ~oR_pR~oR}oR_af@|`f@")
   m1 <- matrix(c(144, 144.1, 144.2, 144, -37, -37.1, -37.2, -37), ncol = 2)
   m2 <- m1 + 1
-  
   m1encoded <- "~py`F__|mZ~oR_pR~oR}oR_af@|`f@"
   m2encoded <- encodeCoordinates(m2[1:4], m2[5:8])
-  
-  multipolygon <- sf::st_sfc(sf::st_multipolygon(
-    list(list(m1, m2))
-  ))
-  
-  expect_true(
-    all(encode(multipolygon)[[1]] %in% c(m1encoded, m2encoded))
-  )
+  multipolygon <- sf::st_sfc(sf::st_multipolygon(list(list(m1, m2))))
+  expect_true(all(encode(multipolygon)[[1]] %in% c(m1encoded, m2encoded)))
 })
 
 
@@ -177,34 +135,13 @@ test_that("sf_GEOMETRYs are encoded", {
     sf::st_sf(geo = polygon),
     sf::st_sf(geo = multipolygon)
   )
-  
-  
   encoded <- encode(sf)
-  
-  expect_true(
-    encoded$geo[[1]] == encode(point)
-  )
-  
-  expect_true(
-    all(encoded$geo[[2]] %in% encode(multipoint)[[1]])
-  )
-  
-  expect_true(
-    encoded$geo[[3]] == encode(linestring)
-  )
-  
-  expect_true(
-    all(encoded$geo[[4]] %in% encode(multilinestring)[[1]])
-  )
-  
-  expect_true(
-    all(encoded$geo[[5]] %in% encode(polygon)[[1]])
-  )
-  
-  expect_true(
-    all(encoded$geo[[6]] %in% encode(multipolygon)[[1]])
-  )
-  
+  expect_true(encoded$geo[[1]] == encode(point))
+  expect_true(all(encoded$geo[[2]] %in% encode(multipoint)[[1]]))
+  expect_true(encoded$geo[[3]] == encode(linestring))
+  expect_true(all(encoded$geo[[4]] %in% encode(multilinestring)[[1]]))
+  expect_true(all(encoded$geo[[5]] %in% encode(polygon)[[1]]))
+  expect_true(all(encoded$geo[[6]] %in% encode(multipolygon)[[1]]))
 })
 
 
@@ -216,26 +153,13 @@ test_that("data.frames are encoded", {
     lineId = c(1,1,1,1),
     lon = c(-80.190, -66.118, -64.757, -80.190),
     lat = c(26.774, 18.466, 32.321, 26.774))
-
-  expect_true(
-    encode(df) == "ohlbDnbmhN~suq@am{tAw`qsAeyhGvkz`@fge}A"
-  )
+  expect_true(encode(df) == "ohlbDnbmhN~suq@am{tAw`qsAeyhGvkz`@fge}A")
 })
 
 test_that("default encoding method errors", {
-  
   testthat::skip_on_cran()
-  
-  expect_error(
-    encode(list()),
-    "I currently don't know how to encode list objects"
-  )
-  
-  expect_error(
-    encode(NULL),
-    "I currently don't know how to encode NULL objects"
-  )
-  
+  expect_error(encode(list()),"I currently don't know how to encode list objects")
+  expect_error(encode(NULL),"I currently don't know how to encode NULL objects")
 })
 
 test_that("GEOMETRYCOLLECTIONS error", {
@@ -250,17 +174,10 @@ test_that("GEOMETRYCOLLECTIONS error", {
   p1 <- as.matrix(df[1:4, c("lon", "lat")])
   p2 <- as.matrix(df[5:8, c("lon", "lat")])
   p3 <- as.matrix(df[9:12, c("lon", "lat")])
-  
   point <- sf::st_point(x = c(df[1,"lon"], df[1,"lat"]))
   polygon <- sf::st_polygon(x = list(p1, p2))
   linestring <- sf::st_linestring(p3)
-  
   sf <- sf::st_sfc(geo = sf::st_geometrycollection(x = list(point, linestring, polygon)))
-  
-  expect_error(
-    encode(sf),
-    "encoding this sf type is currently not supported"
-  )
-  
+  expect_error(encode(sf),"encoding this sf type is currently not supported")
 })
 
